summaryrefslogtreecommitdiffstats
path: root/python/pykde/extra/kde320/kurifilter.h
diff options
context:
space:
mode:
Diffstat (limited to 'python/pykde/extra/kde320/kurifilter.h')
-rw-r--r--python/pykde/extra/kde320/kurifilter.h82
1 files changed, 41 insertions, 41 deletions
diff --git a/python/pykde/extra/kde320/kurifilter.h b/python/pykde/extra/kde320/kurifilter.h
index 8c5f5fe7..834bff8a 100644
--- a/python/pykde/extra/kde320/kurifilter.h
+++ b/python/pykde/extra/kde320/kurifilter.h
@@ -25,9 +25,9 @@
#ifndef __kurifilter_h__
#define __kurifilter_h__ "$Id: kurifilter.h,v 1.41 2003/08/30 08:56:21 raabe Exp $"
-#include <qptrlist.h>
-#include <qobject.h>
-#include <qstringlist.h>
+#include <tqptrlist.h>
+#include <tqobject.h>
+#include <tqstringlist.h>
#include <kurl.h>
#include <kdemacros.h>
@@ -51,7 +51,7 @@ class KCModule;
* \b Example
*
* \code
-* QString text = "kde.org";
+* TQString text = "kde.org";
* KURIFilterData d = text;
* bool filtered = KURIFilter::self()->filter( d );
* cout << "URL: " << text.latin1() << endl
@@ -114,7 +114,7 @@ public:
*
* @param url is the string to be filtered.
*/
- KURIFilterData( const QString& url ) { init( url ); }
+ KURIFilterData( const TQString& url ) { init( url ); }
/**
* Copy constructor.
@@ -158,11 +158,11 @@ public:
* This functions returns the error message set
* by the plugin whenever the uri type is set to
* KURIFilterData::ERROR. Otherwise, it returns
- * a QString::null.
+ * a TQString::null.
*
* @return the error message or a NULL when there is none.
*/
- QString errorMsg() const { return m_strErrMsg; }
+ TQString errorMsg() const { return m_strErrMsg; }
/**
* Returns the URI type.
@@ -182,7 +182,7 @@ public:
*
* @param url the string to be filtered.
*/
- void setData( const QString& url ) { init( url ); }
+ void setData( const TQString& url ) { init( url ); }
/**
* Same as above except the argument is a URL.
@@ -209,14 +209,14 @@ public:
* @param abs_path the abolute path to the local resource.
* @return true if absolute path is successfully set. Otherwise, false.
*/
- bool setAbsolutePath( const QString& abs_path );
+ bool setAbsolutePath( const TQString& abs_path );
/**
* Returns the absolute path if one has already been set.
* @return the absolute path, or QString::null
* @see hasAbsolutePath()
*/
- QString absolutePath() const;
+ TQString absolutePath() const;
/**
* Checks whether the supplied data had an absolute path.
@@ -229,9 +229,9 @@ public:
* Returns the command line options and arguments for a
* local resource when present.
*
* @return options and arguments when present, otherwise QString::null
*/
- QString argsAndOptions() const;
+ TQString argsAndOptions() const;
/**
* Checks whether the current data is a local resource with
@@ -249,9 +249,9 @@ public:
* is found.
*
* @return the name of the icon associated with the resource,
* or QString::null if not found
*/
- QString iconName();
+ TQString iconName();
/**
* Check whether the provided uri is executable or not.
@@ -277,7 +277,7 @@ public:
* @return the string as typed by the user, before any URL processing is done
* @since 3.2
*/
- QString typedString() const;
+ TQString typedString() const;
/**
* Overloaded assigenment operator.
@@ -297,7 +297,7 @@ public:
*
* @return an instance of a KURIFilterData object.
*/
- KURIFilterData& operator=( const QString& url ) { init( url ); return *this; }
+ KURIFilterData& operator=( const TQString& url ) { init( url ); return *this; }
protected:
@@ -311,14 +311,14 @@ protected:
* Initializes the KURIFilterData on construction.
* @param url the URL to initialize the object with
*/
- void init( const QString& url = QString::null );
+ void init( const TQString& url = TQString::null );
private:
bool m_bCheckForExecutables;
bool m_bChanged;
- QString m_strErrMsg;
- QString m_strIconName;
+ TQString m_strErrMsg;
+ TQString m_strIconName;
KURL m_pURI;
URITypes m_iType;
@@ -352,14 +352,14 @@ public:
* @param name the name of the plugin, or 0 for no name
* @param pri the priority of the plugin.
*/
- KURIFilterPlugin( QObject *parent = 0, const char *name = 0, double pri = 1.0 );
+ KURIFilterPlugin( TQObject *parent = 0, const char *name = 0, double pri = 1.0 );
/**
* Returns the filter's name.
*
* @return A string naming the filter.
*/
- virtual QString name() const { return m_strName; }
+ virtual TQString name() const { return m_strName; }
/**
* Returns the filter's priority.
@@ -387,14 +387,14 @@ public:
*
* @return A configuration module, 0 if the filter isn't configurable.
*/
- virtual KCModule *configModule( QWidget*, const char* ) const { return 0; }
+ virtual KCModule *configModule( TQWidget*, const char* ) const { return 0; }
/**
* Returns the name of the configuration module for the filter.
*
* @return the name of a configuration module or QString::null if none.
*/
- virtual QString configName() const { return name(); }
+ virtual TQString configName() const { return name(); }
protected:
@@ -406,7 +406,7 @@ protected:
/**
* Sets the error message in @p data to @p errormsg.
*/
- void setErrorMsg ( KURIFilterData& data, const QString& errmsg ) const {
+ void setErrorMsg ( KURIFilterData& data, const TQString& errmsg ) const {
data.m_strErrMsg = errmsg;
}
@@ -422,9 +422,9 @@ protected:
* Sets the arguments and options string in @p data
* to @p args if any were found during filterting.
*/
- void setArguments( KURIFilterData& data, const QString& args ) const;
+ void setArguments( KURIFilterData& data, const TQString& args ) const;
- QString m_strName;
+ TQString m_strName;
double m_dblPriority;
protected:
@@ -437,7 +437,7 @@ private:
/**
* A list of filter plugins.
*/
-class KURIFilterPluginList : public QPtrList<KURIFilterPlugin>
+class KURIFilterPluginList : public TQPtrList<KURIFilterPlugin>
{
public:
virtual int compareItems(Item a, Item b)
@@ -491,25 +491,25 @@ private:
* of a boolean flag:
*
* \code
- * QString u = KURIFilter::self()->filteredURI( "kde.org" );
+ * TQString u = KURIFilter::self()->filteredURI( "kde.org" );
* \endcode
*
* You can also restrict the filter(s) to be used by supplying
* the name of the filter(s) to use. By defualt all available
* filters will be used. To use specific filters, add the names
* of the filters you want to use to a QStringList and invoke
* the appropriate filtering function. The examples below show
* the use of specific filters. The first one uses a single
* filter called kshorturifilter while the second example uses
* multiple filters:
*
* \code
- * QString text = "kde.org";
+ * TQString text = "kde.org";
* bool filtered = KURIFilter::self()->filterURI( text, "kshorturifilter" );
* \endcode
*
* \code
- * QStringList list;
+ * TQStringList list;
* list << "kshorturifilter" << "localdomainfilter";
* bool filtered = KURIFilter::self()->filterURI( text, list );
* \endcode
@@ -546,7 +546,7 @@ public:
*
* @return a boolean indicating whether the URI has been changed
*/
- bool filterURI( KURIFilterData& data, const QStringList& filters = QStringList() );
+ bool filterURI( KURIFilterData& data, const TQStringList& filters = TQStringList() );
/**
* Filters the URI given by the URL.
@@ -559,7 +559,7 @@ public:
*
* @return a boolean indicating whether the URI has been changed
*/
- bool filterURI( KURL &uri, const QStringList& filters = QStringList() );
+ bool filterURI( KURL &uri, const TQStringList& filters = TQStringList() );
/**
* Filters a string representing a URI.
@@ -572,7 +572,7 @@ public:
*
* @return a boolean indicating whether the URI has been changed
*/
- bool filterURI( QString &uri, const QStringList& filters = QStringList() );
+ bool filterURI( TQString &uri, const TQStringList& filters = TQStringList() );
/**
* Returns the filtered URI.
@@ -585,7 +585,7 @@ public:
*
* @return the filtered URI or null if it cannot be filtered
*/
- KURL filteredURI( const KURL &uri, const QStringList& filters = QStringList() );
+ KURL filteredURI( const KURL &uri, const TQStringList& filters = TQStringList() );
/**
* Return a filtered string representation of a URI.
@@ -598,7 +598,7 @@ public:
*
* @return the filtered URI or null if it cannot be filtered
*/
- QString filteredURI( const QString &uri, const QStringList& filters = QStringList() );
+ TQString filteredURI( const TQString &uri, const TQStringList& filters = TQStringList() );
/**
* Return an iterator to iterate over all loaded
@@ -606,15 +606,15 @@ public:
*
* @return a plugin iterator.
*/
- QPtrListIterator<KURIFilterPlugin> pluginsIterator() const;
+ TQPtrListIterator<KURIFilterPlugin> pluginsIterator() const;
/**
* Return a list of the names of all loaded plugins.
*
* @return a QStringList of plugin names
* @since 3.1
*/
- QStringList pluginNames() const;
+ TQStringList pluginNames() const;
protected:
@@ -209,14 +209,14 @@ public:
/**
* Returns the absolute path if one has already been set.
- * @return the absolute path, or QString::null
+ * @return the absolute path, or TQString::null
* @see hasAbsolutePath()
*/
@@ -229,9 +229,9 @@ public:
* local resource when present.
*
- * @return options and arguments when present, otherwise QString::null
+ * @return options and arguments when present, otherwise TQString::null
*/
@@ -249,9 +249,9 @@ public:
*
* @return the name of the icon associated with the resource,
- * or QString::null if not found
+ * or TQString::null if not found
*/
@@ -387,14 +387,14 @@ public:
* Returns the name of the configuration module for the filter.
*
- * @return the name of a configuration module or QString::null if none.
+ * @return the name of a configuration module or TQString::null if none.
*/
@@ -491,25 +491,25 @@ private:
* the name of the filter(s) to use. By defualt all available
* filters will be used. To use specific filters, add the names
- * of the filters you want to use to a QStringList and invoke
+ * of the filters you want to use to a TQStringList and invoke
* the appropriate filtering function. The examples below show
* the use of specific filters. The first one uses a single
@@ -606,15 +606,15 @@ public:
* Return a list of the names of all loaded plugins.
*
- * @return a QStringList of plugin names
+ * @return a TQStringList of plugin names
* @since 3.1
*/